@@ -14,6 +14,9 @@ from spark_pipeline_framework.transformers.framework_transformer.v1.framework_tr
 from spark_pipeline_framework.utilities.parallel_pipeline_executor.v1.parallel_pipeline_executor import (
     ParallelPipelineExecutor,
 )
+from spark_pipeline_framework.utilities.spark_data_frame_helpers import (
+    create_empty_dataframe,
+)
 
 
 class FrameworkParallelExecutor(FrameworkTransformer):
@@ -93,7 +96,8 @@ class FrameworkParallelExecutor(FrameworkTransformer):
             if progress_logger is not None:
                 progress_logger.write_to_log(
                     self.getName() or "FrameworkTransformerGroup",
-                    f"Skipping stages because enable {self.enable or self.enable_if_view_not_empty} did not evaluate to True",
+                    f"Skipping stages because enable "
+                    + f"{self.enable or self.enable_if_view_not_empty} did not evaluate to True",
                 )
 
         return df
@@ -130,9 +134,13 @@ class FrameworkParallelExecutor(FrameworkTransformer):
             # convert each stage into a list of stages, so it can run in parallel
             pipeline_executor.append(name=stage_name, list_of_stages=[stage])
 
+        # use a new df everytime to avoid keeping data in memory too long
+        df.unpersist(blocking=True)
+        df = create_empty_dataframe(df.sparkSession)
+
         async for name, _ in pipeline_executor.transform_async(df, df.sparkSession):
             if name:
-                logger.info(f"Finished running {name}")
+                logger.info(f"Finished running parallel stage {name}")
 
         logger.info("Finished process_async")
 
